@@ -24,7 +24,6 @@ import base64
 import contextlib
 import datetime
 import inspect
-import os
 import random as rnd_module
 import traceback
 import warnings
@@ -485,11 +484,6 @@ def new_given_argspec(original_argspec, generator_kwargs):
     )
 
 
-ROOT = os.path.dirname(__file__)
-
-STDLIB = os.path.dirname(os.__file__)
-
-
 class StateForActualGivenExecution(object):
     def __init__(self, test_runner, search_strategy, test, settings, random, had_seed):
         self.test_runner = test_runner
